Description Usage Format Examples
This R workspace contains three simulated datasets based on negative binomial Poisson (NBP) distribution.
Specifically, SIM1 is obtained from function Sim1.
SIM2 and SIM3 are obtained from function Sim2, with different parameters.
1 |
Three data matrices each with 150 samples (50 per group) and 5000 genes.
SIM1An integer-valued matrix simulated by Sim1. For more details see the help page of Sim1.
SIM2An integer-valued matrix simulated by Sim2. For more details see the help page of Sim2.
SIM3An integer-valued matrix simulated by Sim2. For more details see the help page of Sim2.
1 2 3 4 5 6 7 8 | ## Load the sample data
data(SampleData)
## Number of genes and samples
ngenes <- 5000; n1 <- n2 <- n3 <- 50
Groups <- c(rep("A",n1), rep("B",n2), rep("C",n3))
mod1 <- superdelta2(mydata = SIM1, offset = 1, Grps = Groups)
mod2 <- superdelta2(mydata = SIM2, offset = 1, Grps = Groups)
mod3 <- superdelta2(mydata = SIM3, offset = 1, Grps = Groups)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.